@@ -512,6 +512,20 @@ class PythonInterpreter(ExampleRunner, PexpectMixin):
             ]
         }
 
+    def get_default_version_cmd(self, *args, **kargs):
+        p = self._python_flavor
+        return "%e %p %a", {
+            'e': "/usr/bin/env",
+            'p': p,
+            'a': [
+                "--version",
+            ]
+        }
+
+    @constant
+    def get_version(self, options):
+        return self._get_version(options)
+
     def conf_pretty_print(self, columns, options):
         # Important: do not use a single quote ' in the following python code
         # it will break it in real hard ways to debug.
@@ -565,10 +579,7 @@ if True:
         pretty_print = (py_doctest and py_pretty_print) \
                         or not py_doctest
 
-        shebang, tokens = self.get_default_cmd()
-        shebang = options['shebangs'].get(self.language, shebang)
-
-        cmd = ShebangTemplate(shebang).quote_and_substitute(tokens)
+        cmd = self.build_cmd(options, *self.get_default_cmd())
 
         # run!
         self._spawn_interpreter(cmd, options, initial_prompt=r'>>> ')
